"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ThemeConfig = /** @class */ (function () {
    function ThemeConfig() {
        this.themeChangeHandlers = [];
        this.loadTheme = function () { return localStorage.getItem('theme') || 'light'; };
        this.saveTheme = function (theme) { return localStorage.setItem('theme', theme); };
    }
    ThemeConfig.prototype.initTheme = function () {
        this.displayTheme(this.getTheme());
    };
    ThemeConfig.prototype.getTheme = function () {
        return this.loadTheme() || (window.matchMedia('(prefers-color-scheme: dark)').matches ? 'dark' : 'light');
    };
    ThemeConfig.prototype.setTheme = function (theme) {
        this.saveTheme(theme);
        this.displayTheme(theme);
    };
    ThemeConfig.prototype.displayTheme = function (theme) {
        document.body.setAttribute('data-theme', theme);
        for (var _i = 0, _a = this.themeChangeHandlers; _i < _a.length; _i++) {
            var handler = _a[_i];
            handler(theme);
        }
    };
    return ThemeConfig;
}());
exports.ThemeConfig = ThemeConfig;
function writeDarkSwitch(config) {
    document.write("\n<div class=\"custom-control custom-switch\">\n<input type=\"checkbox\" class=\"custom-control-input\" id=\"darkSwitch\">\n<label class=\"custom-control-label\" for=\"darkSwitch\">Dark Mode</label>\n</div>\n");
    var darkSwitch = document.getElementById('darkSwitch');
    darkSwitch.checked = config.getTheme() === 'dark';
    darkSwitch.onchange = function () {
        config.setTheme(darkSwitch.checked ? 'dark' : 'light');
    };
    config.themeChangeHandlers.push(function (theme) { return darkSwitch.checked = theme === 'dark'; });
    return darkSwitch;
}
exports.writeDarkSwitch = writeDarkSwitch;
